from . import line_chart
from . import scatter_plot
from . import axes
from . import figure
from . import layout
from . import histogram

Axes = axes.Axes
Figure = figure.Figure
Graphics = graphic.Graphic
LineChart = line_chart.LineChart
ScatterPlot = scatter_plot.ScatterPlot
Histogram = histogram.Histogram